@@ -1,7 +1,8 @@
 #!/bin/sh
 
-#  mirrpg v. 0.0.1-pre11 
+#  mirrpg v. 0.0.2
 #  Copyright (C) 2001 Davide Angelocola
+#  Updated by Calle Laakkonen in 2004
 #
 #  This program is free software; you can redistribute it and/or
 #  modify it under the terms of the GNU General Public License as
@@ -20,19 +21,21 @@
 #  Author: Davide Angelocola <davide178@inwind.it>
 
 options="--indent-level4"
-options="$options --break-function-decl-args"
 options="$options --ignore-profile"
 options="$options --preserve-mtime"
-options="$options -bl"
-options="$options -bli0"
+options="$options -br"
 options="$options -cdw"
 options="$options -lp"
-options="$options -bls"
-options="$options -bfda"
+options="$options -brs"
+options="$options -nbfda"
+options="$options -nbfde"
+options="$options -npsl"
+options="$options -ce"
+options="$options -nut"
 
-for coin in `find . -name "*.[ch]" -print`
+for coin in *.[ch]
 do
- echo "indenting... `basename $coin`"
+ echo "indenting... $coin"
  indent $options $coin 
  rm $coin~ -f
 done 
