@@ -1,6 +1,6 @@
 #!/bin/bash
 
-for i in `ls --color=no *.pack`
+for i in *.pack
 do
   echo "LDAT: $i"
   ldat --pack --index $i
