@@ -1,6 +1,6 @@
 /*
  * Luola - 2D multiplayer cavern-flying game
- * Copyright (C) 2003 Calle Laakkonen
+ * Copyright (C) 2001-2005 Calle Laakkonen
  *
  * File        : animation.h
  * Description : This module handles all the animation and redraw timings
@@ -24,15 +24,12 @@
 #ifndef ANIMATION_HEADER
 #define ANIMATION_HEADER
 
-/* Events */
-#define EVENT_ANIMATE_FRAME   1
-
 /* Functions */
-extern void init_animation(void);
-extern void reinit_animation(void);
-extern Uint8 pause_game(void);
+extern void init_animation (void);
+extern void reinit_animation (void);
+extern Uint8 pause_game (void);
 
-extern void animate_frame(void);
+extern void animate_frame (void);
 
 /* Globals */
 extern int endgame;
