@@ -396,6 +396,29 @@ SDL_Surface *scale_surface (SDL_Surface * original, int sX, int sY,
 
 #endif
 
+/* Wait for a keypress */
+/* Also handles screenshot and toggling between fullscreen
+ * and windowed mode.
+ */
+void wait_for_enter(void) {
+    SDL_Event e;
+    while(1) {
+        SDL_WaitEvent(&e);
+        if(e.type==SDL_KEYDOWN) {
+            if(e.key.keysym.sym == SDLK_RETURN) {
+                if((e.key.keysym.mod & (KMOD_LALT|KMOD_RALT)))
+                    SDL_WM_ToggleFullScreen(screen);
+                else
+                    break;
+            } else if(e.key.keysym.sym == SDLK_F11) {
+                screenshot();
+            }
+        } else if(e.type==SDL_JOYBUTTONDOWN)
+            break;
+    }
+}
+
+/* Translate joystick button press to keypress */
 void joystick_button (SDL_JoyButtonEvent * btn) {
     SDL_Event event;
     event.key.state = btn->state;
@@ -408,6 +431,7 @@ void joystick_button (SDL_JoyButtonEvent * btn) {
     SDL_PushEvent (&event);
 }
 
+/* Translate joystick motion to keypress */
 void joystick_motion (SDL_JoyAxisEvent * axis, char plrmode) {
     SDL_Event event;
     int p, plr = -1;
