@@ -55,8 +55,10 @@ extern void init_sdl (void);
 /* Initialize screen */
 extern void init_video (void);
 
-/* Graphics */
+/* Wait for enter */
+extern void wait_for_enter(void);
 
+/* Graphics */
 extern void kill_plr_screen (unsigned char plr);
 
 extern void draw_box (int x, int y, int w, int h, char width, Uint32 color);
