@@ -28,6 +28,7 @@
 #include "defines.h"
 #include "console.h"
 #include "particle.h"
+#include "stringutil.h"
 #include "critter.h"
 #include "player.h"
 #include "level.h"
@@ -196,8 +197,8 @@ void prepare_critters (LevelSettings * settings)
 Critter *make_critter (CritterSpecies species, int x, int y, signed char owner)
 {
     Critter *newcritter = NULL;
-    unsigned char solid = 0;
     int loop, loop2, r, breakloop;
+    unsigned char medium = 0;
     newcritter = malloc (sizeof (Critter));
     newcritter->health = 1;
     newcritter->explode = 0;
@@ -213,11 +214,11 @@ Critter *make_critter (CritterSpecies species, int x, int y, signed char owner)
         newcritter->rect.x = newcritter->rect.w * owner;
     case Bird:
         newcritter->type = FlyingCritter;
-        solid = TER_FREE;
+        medium = TER_FREE;
         break;
     case Bat:
         newcritter->type = FlyingCritter;
-        solid = TER_FREE;
+        medium = TER_FREE;
         newcritter->health = 2;
         break;
     case Infantry:
@@ -226,29 +227,39 @@ Critter *make_critter (CritterSpecies species, int x, int y, signed char owner)
         newcritter->rect.x = newcritter->rect.w * owner;
     case Cow:
         newcritter->type = GroundCritter;
-        solid = TER_GROUND;
         break;
     case Fish:
         newcritter->type = WaterCritter;
-        solid = TER_WATER;
+        medium = TER_WATER;
         break;
     }
+    /* Find a place for the critter */
     if (x < 0 || y < 0) {
         loop = 0;
-        breakloop = 0;
         if (newcritter->type == GroundCritter) {
             do {
-                newcritter->x = 20 + rand () % (lev_level.width - 40);
-                newcritter->y = 20 + rand () % (lev_level.height - 40);
-                loop++;
-                if (loop > 1000) {
+                if (loop++ > 1000) {
+                    printf("Couldn't find a place for a %s after 1000 tries.\n",
+                            critter2str(species));
                     free (newcritter);
                     return NULL;
                 }
-            } while (lev_level.solid[newcritter->x][newcritter->y] != solid
-                     || lev_level.solid[newcritter->x][newcritter->y - 1] !=
-                     TER_FREE);
-            newcritter->y -= critter_gfx[Cow][0]->h;
+                newcritter->x = 20 + rand () % (lev_level.width - 40);
+                newcritter->y = 20 + rand () % (lev_level.height - 40);
+                if(is_walkable(newcritter->x,newcritter->y)==0 &&
+                        is_water(newcritter->x,newcritter->y)==0) {
+                    do {
+                        newcritter->y++;
+                    } while(newcritter->y<=lev_level.height-20 &&
+                            is_walkable(newcritter->x,newcritter->y)==0 &&
+                            is_water(newcritter->x,newcritter->y)==0);
+                } else {
+                    newcritter->y=lev_level.height;
+                }
+            } while (newcritter->y>lev_level.height-20 ||
+                    is_walkable(newcritter->x,newcritter->y)==0 ||
+                    is_water(newcritter->x,newcritter->y));
+            newcritter->y -= critter_gfx[species][0]->h+1;
         } else {
             loop2 = 0;
             breakloop = 0;
@@ -258,33 +269,39 @@ Critter *make_critter (CritterSpecies species, int x, int y, signed char owner)
                     newcritter->y = 20 + rand () % (lev_level.height - 40);
                     loop++;
                     if (loop > 1000) {
+                        printf("Couldn't find a place for a %s after 1000 tries.\n",
+                            critter2str(species));
                         free (newcritter);
                         return NULL;
                     }
                 } while (lev_level.solid[newcritter->x][newcritter->y] !=
-                         solid);
-                if (species != Bat)
-                    break;
-                /* bats are all asleep when the level begins */
-                for (r = 0; r < 100; r++) {
-                    if (newcritter->y - r < 20)
-                        break;
-                    if (hit_solid
-                        (newcritter->x + newcritter->rect.w / 2,
-                         newcritter->y - r) > 0) {
-                        newcritter->y -= r;
-                        newcritter->carried = (struct Ship *) 1;
-                        newcritter->frame = BAT_FRAMES - 1;
-                        breakloop = 1;
-                        break;
+                         medium);
+                if (species == Bat) {
+                    /* bats are all asleep when the level begins */
+                    for (r = 0; r < 100; r++) {
+                        if (newcritter->y - r < 20)
+                            break;
+                        if (hit_solid
+                            (newcritter->x + newcritter->rect.w / 2,
+                             newcritter->y - r) > 0) {
+                            newcritter->y -= r;
+                            newcritter->carried = (struct Ship *) 1;
+                            newcritter->frame = BAT_FRAMES - 1;
+                            breakloop = 1;
+                            break;
+                        }
                     }
-                }
-                if (breakloop)
+                    if (breakloop)
+                        break;
+                    loop2++;
+                    if (loop2 > 20) {
+                        printf("Couldn't find a place for a %s after 20000 tries.\n",
+                                critter2str(species));
+                        free (newcritter);
+                        return NULL;
+                    }
+                } else {
                     break;
-                loop2++;
-                if (loop2 > 20) {
-                    free (newcritter);
-                    return NULL;
                 }
             }
         }
