@@ -1,6 +1,6 @@
 /*
  * Luola - 2D multiplayer cavern-flying game
- * Copyright (C) 2003 Calle Laakkonen
+ * Copyright (C) 2003-2005 Calle Laakkonen
  *
  * File        : demo.h
  * Description : Eyecandy
@@ -25,18 +25,15 @@
 #define DEMO_H
 
 /* Initializes the demos */
-extern void init_demos(void);
-
-/* Deinitializes the demos */
-extern void deinit_demos(void);
+extern void init_demos (void);
 
 /* Draw an animated starfield animation on screen. */
-extern void draw_starfield(void);
+extern void draw_starfield (void);
 
 /* Fade the screen to black (Note. program is locked up while fading) */
-extern void fade_to_black(void);
+extern void fade_to_black (void);
 
 /* Fade from black to surface (Note. program is locked up while fading) */
-void fade_from_black(SDL_Surface *surface);
+void fade_from_black (SDL_Surface * surface);
 
 #endif
