@@ -226,7 +226,7 @@ int init_font (void) {
 /* Or, if you are using SFont, this is slow if color is */
 /* something else than white				*/
 void putstring_direct (SDL_Surface * surface, FontSize size, int x, int y,
-                       char *text, SDL_Color color)
+                       const char *text, SDL_Color color)
 {
     SDL_Surface *fontsurface;
     SDL_Rect rect;
@@ -263,8 +263,8 @@ void putstring_direct (SDL_Surface * surface, FontSize size, int x, int y,
 
 /* A convenience wrapper for putstring_direct		*/
 /* Centers the string horizontaly			*/
-void centered_string (SDL_Surface * surface, FontSize size, int y, char *text,
-                      SDL_Color color)
+void centered_string (SDL_Surface * surface, FontSize size, int y,
+                      const char *text, SDL_Color color)
 {
     FontInfo font;
     int x, w, h;
@@ -282,7 +282,7 @@ void centered_string (SDL_Surface * surface, FontSize size, int y, char *text,
 /* This is slow with SFont when the you use a color	*/
 /* other than white. The returned surface will be in	*/
 /* the same format as the display			*/
-SDL_Surface *renderstring (FontSize size, char *text, SDL_Color color)
+SDL_Surface *renderstring (FontSize size, const char *text, SDL_Color color)
 {
     SDL_Surface *fontsurface;
     FontInfo font;
@@ -304,11 +304,7 @@ SDL_Surface *renderstring (FontSize size, char *text, SDL_Color color)
         }
         return fontsurface;
     } else {                    /* SDL_ttf version */
-        //SDL_Surface *conv;
         return ttf_rendertext_blended (font.tfont, text, color);
-        //conv=SDL_DisplayFormat(fontsurface);
-        //SDL_FreeSurface(fontsurface);
-        //return conv;
     }
 }
 
