@@ -44,18 +44,18 @@ extern int init_font (void);
 /* This is slow if you use SDL_ttf because 		*/
 /* an extra surface needs to be created and freed 	*/
 extern void putstring_direct (SDL_Surface * surface, FontSize size, int x,
-                              int y, char *text, SDL_Color color);
+                              int y, const char *text, SDL_Color color);
 
 /* A convenience wrapper for putstring_direct		*/
 /* Centers the string horizontaly			*/
 extern void centered_string (SDL_Surface * surface, FontSize size, int y,
-                             char *text, SDL_Color color);
+                             const char *text, SDL_Color color);
 
 /* Return a surface containing the text			*/
 /* This is slow with SFont when the you use a color	*/
 /* other than white. The returned surface will be	*/
 /* in the same format as the display.			*/
-extern SDL_Surface *renderstring (FontSize size, char *text, SDL_Color color);
+extern SDL_Surface *renderstring (FontSize size, const char *text, SDL_Color color);
 
 /* Get the height of the font				*/
 extern int font_height (FontSize size);
