@@ -56,7 +56,7 @@
 #define HOME_PATH "luola/"
 
 /* Get the full path of a filename */
-const char *getfullpath (char dir, char *filename)
+const char *getfullpath (DataDir dir,const char *filename)
 {
     /* static buffer for the filename */
     static char fullpath[1024];
@@ -191,7 +191,7 @@ void check_homedir (void)
 }
 
 /* Load an imagefile */
-SDL_Surface *load_image (char dir, char *filename, char allownull,
+SDL_Surface *load_image (char dir, const char *filename, char allownull,
                          signed char enableAlpha)
 {
     SDL_RWops *rw;
