@@ -30,15 +30,11 @@
 #include "ldat.h"
 
 /* Directories */
-#define GFX_DIRECTORY      	0
-#define FONT_DIRECTORY	   	1
-#define LEVEL_DIRECTORY    	3
-#define USERLEVEL_DIRECTORY	4
-#define HOME_DIRECTORY	   	5
-#define SND_DIRECTORY	   	6
+typedef enum {GFX_DIRECTORY,FONT_DIRECTORY,LEVEL_DIRECTORY,
+    USERLEVEL_DIRECTORY,HOME_DIRECTORY,SND_DIRECTORY} DataDir;
 
 /* Get the full path */
-extern const char *getfullpath (char dir, char *filename);
+extern const char *getfullpath (DataDir dir, const char *filename);
 
 /* Check if home directory exists and create if it doesn't */
 extern void check_homedir (void);
@@ -46,7 +42,7 @@ extern void check_homedir (void);
 /* Read datafiles */
 /* if enableAlpha is 1, the alpha channel will be loaded properly. */
 /* if it is 2, colorkey will be set to the topleft pixel. */
-extern SDL_Surface *load_image (char dir, char *filename, char allownull,
+extern SDL_Surface *load_image (char dir,const char *filename, char allownull,
                                 signed char enableAlpha);
 
 /* This function loads the image from SDL_RWops */
