@@ -97,7 +97,8 @@ int init_game (void)
         game_settings.controller[p] = Keyboard;
     }
     game_settings.ship_collisions = 1;
-    game_settings.ls.indstr_base = 1;
+    game_settings.ls.indstr_base = 0;
+    game_settings.base_regen = 1;
     game_settings.coll_damage = 1;
     game_settings.enable_smoke = 1;
     game_settings.ls.jumpgates = 0;
@@ -165,40 +166,38 @@ void prematch_game (void)
 
 void apply_per_level_settings (LevelSettings * settings)
 {
-    if (settings && settings->override) {
-        level_settings.critters = game_settings.ls.critters
-            || settings->override->critters_enabled;
-        level_settings.stars = settings->override->stars;
-        level_settings.snowfall = settings->override->snowfall;
-        level_settings.turrets = settings->override->turrets;
-        level_settings.jumpgates = settings->override->jumpgates;
-        level_settings.cows = settings->override->cows;
-        level_settings.fish = settings->override->fish;
-        level_settings.birds = settings->override->birds;
-        level_settings.bats = settings->override->bats;
-        level_settings.soldiers = settings->override->soldiers;
-        level_settings.helicopters = settings->override->helicopters;
-        level_settings.indstr_base = settings->override->indstr_base;
-    } else {
-        level_settings = game_settings.ls;
+    level_settings = game_settings.ls;
+    if (settings->override) {
+        LSB_Override *o=settings->override;
+        if(o->indstr_base>=0) level_settings.indstr_base=o->indstr_base;
+        if(o->critters>=0) level_settings.critters=o->critters;
+        if(o->stars>=0) level_settings.stars=o->stars;
+        if(o->snowfall>=0) level_settings.snowfall=o->snowfall;
+        if(o->turrets>=0) level_settings.turrets=o->turrets;
+        if(o->jumpgates>=0) level_settings.jumpgates=o->jumpgates;
+        if(o->cows>=0) level_settings.cows=o->cows;
+        if(o->fish>=0) level_settings.fish=o->fish;
+        if(o->birds>=0) level_settings.birds=o->birds;
+        if(o->bats>=0) level_settings.bats=o->bats;
+        if(o->soldiers>=0) level_settings.soldiers=o->soldiers;
+        if(o->helicopters>=0) level_settings.helicopters=o->helicopters;
     }
 }
 
 void game_statistics (void)
 {
     Uint32 color, sep_col, team_col, plr_col;
-    SDL_Event event;
     SDL_Rect rect1, rect2;
     int t, p, teams[4];
     char tmps[256];
-    char data[8][3][32];        /* Four teams and four players */
+    char data[8][3][32];    /* Four teams and four players */
     char summary[128];
-    char data_format[8];        /* Some formatting instructions */
+    char data_format[8];    /* Some formatting instructions */
     int data_line, team_data_line;
     long int avglife;
     int mostwins;
     char tiegame;
-    int x, y, x2, y2;           /* Variables used when outputting data to screen */
+    int x, y, x2, y2;       /* Variables used when outputting data to screen */
 #if HAVE_LIBSDL_GFX
     color = 0xC85050FF;
     sep_col = 0x5050FFF0;
@@ -348,13 +347,7 @@ void game_statistics (void)
                      "Press enter to continue", font_color_white);
     SDL_UpdateRect (screen, rect1.x, rect1.y, rect1.w, rect1.h);
     /* Wait for Enter to be pressed */
-    while (1) {
-        SDL_WaitEvent (&event);
-        if (event.type == SDL_KEYDOWN && event.key.keysym.sym == SDLK_RETURN)
-            break;
-        if (event.type == SDL_JOYBUTTONDOWN)
-            break;
-    }
+    wait_for_enter();
 }
 
 void fill_unused_player_screens (void)
@@ -403,8 +396,9 @@ void game_eventloop (void) {
                 else if (Event.key.keysym.sym == SDLK_F11
                          && Event.type == SDL_KEYDOWN)
                     screenshot ();
-                else if (Event.key.keysym.sym == SDLK_F12
-                         && Event.type == SDL_KEYUP)
+                else if (Event.key.keysym.sym == SDLK_RETURN
+                         && Event.type == SDL_KEYUP
+                         && (Event.key.keysym.mod & (KMOD_LALT|KMOD_RALT)))
                     SDL_WM_ToggleFullScreen (screen);
                 else if (Event.key.keysym.sym == SDLK_PAUSE
                          && Event.type == SDL_KEYUP)
@@ -464,6 +458,7 @@ void save_game_config (void)
     fprintf (fp, "[settings]\n");
     fprintf (fp, "ship_collisions=%d\n", game_settings.ship_collisions);
     fprintf (fp, "indestructable_base=%d\n", game_settings.ls.indstr_base);
+    fprintf (fp, "regenerate_base=%d\n", game_settings.base_regen);
     fprintf (fp, "collision_damage=%d\n", game_settings.coll_damage);
     fprintf (fp, "jumpgates=%d\n", game_settings.ls.jumpgates);
     fprintf (fp, "jumplife=%d\n", game_settings.jumplife);
@@ -498,39 +493,40 @@ void save_game_config (void)
 
 /* Parse configuration file settings block */
 static void parse_settings_block(struct dllist *values) {
-    CfgPtrType types[29];
-    void *pointers[29];
-    char *keys[29];
+    CfgPtrType types[30];
+    void *pointers[30];
+    char *keys[30];
 
     keys[0]="ship_collisions";      types[0]=CFG_INT; pointers[0]=&game_settings.ship_collisions;
     keys[1]="indestructable_base";  types[1]=CFG_INT; pointers[1]=&game_settings.ls.indstr_base;
-    keys[2]="collision_damage";     types[2]=CFG_INT; pointers[2]=&game_settings.coll_damage;
-    keys[3]="jumpgates";            types[3]=CFG_INT; pointers[3]=&game_settings.ls.jumpgates;
-    keys[4]="jumplife";             types[4]=CFG_INT; pointers[4]=&game_settings.jumplife;
-    keys[5]="turrets";              types[5]=CFG_INT; pointers[5]=&game_settings.ls.turrets;
-    keys[6]="critters";             types[6]=CFG_INT; pointers[6]=&game_settings.ls.critters;
-    keys[7]="cows";                 types[7]=CFG_INT; pointers[7]=&game_settings.ls.cows;
-    keys[8]="birds";                types[8]=CFG_INT; pointers[8]=&game_settings.ls.birds;
-    keys[9]="fish";                 types[9]=CFG_INT; pointers[9]=&game_settings.ls.fish;
-    keys[10]="soldiers";            types[10]=CFG_INT;pointers[10]=&game_settings.ls.soldiers;
-    keys[11]="helicopters";         types[11]=CFG_INT;pointers[11]=&game_settings.ls.helicopters;
-    keys[12]="bats";                types[12]=CFG_INT;pointers[12]=&game_settings.ls.bats;
-    keys[13]="smoke";               types[13]=CFG_INT;pointers[13]=&game_settings.enable_smoke;
-    keys[14]="bullet_gravity";      types[14]=CFG_INT;pointers[14]=&game_settings.gravity_bullets;
-    keys[15]="bullet_wind";         types[15]=CFG_INT;pointers[15]=&game_settings.wind_bullets;
-    keys[16]="snowfall";            types[16]=CFG_INT;pointers[16]=&game_settings.ls.snowfall;
-    keys[17]="stars";               types[17]=CFG_INT;pointers[17]=&game_settings.ls.stars;
-    keys[18]="endmode";             types[18]=CFG_INT;pointers[18]=&game_settings.endmode;
-    keys[19]="weapon_switch";       types[19]=CFG_INT;pointers[19]=&game_settings.weapon_switch;
-    keys[20]="eject";               types[20]=CFG_INT;pointers[20]=&game_settings.eject;
-    keys[21]="explosions";          types[21]=CFG_INT;pointers[21]=&game_settings.explosions;
-    keys[22]="holesize";            types[22]=CFG_INT;pointers[22]=&game_settings.holesize;
-    keys[23]="recall";              types[23]=CFG_INT;pointers[23]=&game_settings.recall;
-    keys[24]="criticalhits";        types[24]=CFG_INT;pointers[24]=&game_settings.criticals;
-    keys[25]="sounds";              types[25]=CFG_INT;pointers[25]=&game_settings.sounds;
-    keys[26]="music";               types[26]=CFG_INT;pointers[26]=&game_settings.music;
-    keys[27]="playlist";            types[27]=CFG_INT;pointers[27]=&game_settings.playlist;
-    keys[28]="music_volume";        types[28]=CFG_INT;pointers[28]=&game_settings.music_vol;
+    keys[2]="regenerate_base";      types[2]=CFG_INT; pointers[2]=&game_settings.base_regen;
+    keys[3]="collision_damage";     types[3]=CFG_INT; pointers[3]=&game_settings.coll_damage;
+    keys[4]="jumpgates";            types[4]=CFG_INT; pointers[4]=&game_settings.ls.jumpgates;
+    keys[5]="jumplife";             types[5]=CFG_INT; pointers[5]=&game_settings.jumplife;
+    keys[6]="turrets";              types[6]=CFG_INT; pointers[6]=&game_settings.ls.turrets;
+    keys[7]="critters";             types[7]=CFG_INT; pointers[7]=&game_settings.ls.critters;
+    keys[8]="cows";                 types[8]=CFG_INT; pointers[8]=&game_settings.ls.cows;
+    keys[9]="birds";                types[9]=CFG_INT; pointers[9]=&game_settings.ls.birds;
+    keys[10]="fish";                 types[10]=CFG_INT; pointers[10]=&game_settings.ls.fish;
+    keys[11]="soldiers";            types[11]=CFG_INT;pointers[11]=&game_settings.ls.soldiers;
+    keys[12]="helicopters";         types[12]=CFG_INT;pointers[12]=&game_settings.ls.helicopters;
+    keys[13]="bats";                types[13]=CFG_INT;pointers[13]=&game_settings.ls.bats;
+    keys[14]="smoke";               types[14]=CFG_INT;pointers[14]=&game_settings.enable_smoke;
+    keys[15]="bullet_gravity";      types[15]=CFG_INT;pointers[15]=&game_settings.gravity_bullets;
+    keys[16]="bullet_wind";         types[16]=CFG_INT;pointers[16]=&game_settings.wind_bullets;
+    keys[17]="snowfall";            types[17]=CFG_INT;pointers[17]=&game_settings.ls.snowfall;
+    keys[18]="stars";               types[18]=CFG_INT;pointers[18]=&game_settings.ls.stars;
+    keys[19]="endmode";             types[19]=CFG_INT;pointers[19]=&game_settings.endmode;
+    keys[20]="weapon_switch";       types[20]=CFG_INT;pointers[20]=&game_settings.weapon_switch;
+    keys[21]="eject";               types[21]=CFG_INT;pointers[21]=&game_settings.eject;
+    keys[22]="explosions";          types[22]=CFG_INT;pointers[22]=&game_settings.explosions;
+    keys[23]="holesize";            types[23]=CFG_INT;pointers[23]=&game_settings.holesize;
+    keys[24]="recall";              types[24]=CFG_INT;pointers[24]=&game_settings.recall;
+    keys[25]="criticalhits";        types[25]=CFG_INT;pointers[25]=&game_settings.criticals;
+    keys[26]="sounds";              types[26]=CFG_INT;pointers[26]=&game_settings.sounds;
+    keys[27]="music";               types[27]=CFG_INT;pointers[27]=&game_settings.music;
+    keys[28]="playlist";            types[28]=CFG_INT;pointers[28]=&game_settings.playlist;
+    keys[29]="music_volume";        types[29]=CFG_INT;pointers[29]=&game_settings.music_vol;
     translate_config(values,sizeof(types)/sizeof(CfgPtrType),keys,types,pointers,0);
 }
 
