@@ -28,14 +28,16 @@
 
 #include "lconf.h"
 
-#define PLAYMODE_COUNT 4
+#define PLAYMODE_COUNT 5
 
 typedef enum { Keyboard, Pad1, Pad2, Pad3, Pad4 } ControllerType;
 typedef enum { Forward, Backward, Left, Right, Weap1, Weap2 } Keys;
-typedef enum { Normal, OutsideShip, OutsideShip1, RndCritical } Playmode;
+typedef enum { Normal, OutsideShip, OutsideShip1, RndCritical,RndWeapon } Playmode;
 
 extern unsigned int Controllers;
 
+struct dllist;
+
 typedef struct {
     int indstr_base;
     int jumpgates;
@@ -54,9 +56,9 @@ typedef struct {
     ControllerType controller[4];
     SDLKey buttons[4][6];       /* Forward, Backward, Left,Right,Weap1,Weap2 */
 
-    struct LevelFile *levels;
-    struct LevelFile *first_level;
-    struct LevelFile *last_level;
+    struct dllist *levels;
+    struct dllist *first_level;
+    struct dllist *last_level;
     int levelcount;
     /* General game settings */
     int ship_collisions;
@@ -74,6 +76,7 @@ typedef struct {
     int criticals;
     /* Level settings */
     PerLevelSettings ls;
+    int base_regen;
     /* Audio settings */
     int sounds;
     int music;
