@@ -79,10 +79,10 @@ static Uint8 hotseat_startup_eventloop (void);
 static Uint8 hotseat_weaponsel_eventloop (void);
 
 /* Functions called by menu callbacks */
-SDL_Surface *ship_icon (Uint8 mid, MenuItem * item);
-int menu_icon_spacer (int x, int y, Uint8 align, int mid, MenuItem * item);
-Uint8 menu_toggle_player (MenuCommand cmd, int mid, MenuItem * item);
-char *hotseat_label_function (int mid, MenuItem * item);
+static SDL_Surface *ship_icon (Uint8 mid, MenuItem * item);
+static int menu_icon_spacer (int x, int y, Uint8 align, int mid, MenuItem * item);
+static Uint8 menu_toggle_player (MenuCommand cmd, int mid, MenuItem * item);
+static char *hotseat_label_function (int mid, MenuItem * item);
 
 /* Initialize */
 int init_hotseat (void) {
@@ -182,25 +182,25 @@ void hotseat_game (void)
         fade_to_black ();
     game_status.total_rounds = 0;
     while (game_settings.rounds > 0) {
+        struct LevelFile *curlevel;
         prematch_game ();
         rval = hotseat_weaponsel ();
         if (rval)
             break;
+        curlevel = game_settings.levels->data;
         fill_unused_player_screens ();
-        load_level (game_settings.levels);
-        apply_per_level_settings (game_settings.levels->settings);
-        prepare_specials (game_settings.levels->settings);
-        prepare_critters (game_settings.levels->settings);
+        load_level (curlevel);
+        apply_per_level_settings(curlevel->settings);
+        prepare_specials (curlevel->settings);
+        prepare_critters (curlevel->settings);
+
         clear_weapons ();
         clear_particles ();
         reinit_players ();
-        reinit_ships (game_settings.levels->settings);
+        reinit_ships (curlevel->settings);
         prepare_weather ();
 #if HAVE_LIBSDL_MIXER
-        if (game_settings.levels->settings)
-            bgm = game_settings.levels->settings->mainblock->music;
-        else
-            bgm = NULL;
+        bgm = curlevel->settings->mainblock->music;
         if (bgm) {
             music_newplaylist ();
             while (bgm) {
@@ -212,6 +212,14 @@ void hotseat_game (void)
         }
         music_play ();
 #endif
+        if(game_settings.playmode==RndWeapon) {
+            for(r=0;r<4;r++) {
+                if(players[r].state==ALIVE) {
+                    set_player_message(r,Smallfont,font_color_green,25,
+                            weap2str(players[r].specialWeapon));
+                }
+            }
+        }
         game_eventloop ();
         if (game_settings.mbg_anim)
             fade_to_black ();
@@ -284,8 +292,6 @@ Uint8 hotseat_startup_eventloop (void)
                 command = -1;
                 if (Event.key.keysym.sym == SDLK_F11)
                     screenshot ();
-                else if (Event.key.keysym.sym == SDLK_F12)
-                    SDL_WM_ToggleFullScreen (screen);
                 else if (Event.key.keysym.sym == SDLK_UP)
                     command = MenuUp;
                 else if (Event.key.keysym.sym == SDLK_DOWN)
@@ -294,9 +300,12 @@ Uint8 hotseat_startup_eventloop (void)
                     command = MenuLeft;
                 else if (Event.key.keysym.sym == SDLK_RIGHT)
                     command = MenuRight;
-                else if (Event.key.keysym.sym == SDLK_RETURN)
-                    command = MenuEnter;
-                else if (Event.key.keysym.sym == SDLK_ESCAPE)
+                else if (Event.key.keysym.sym == SDLK_RETURN) {
+                    if((Event.key.keysym.mod & (KMOD_LALT|KMOD_RALT)))
+                        SDL_WM_ToggleFullScreen (screen);
+                    else
+                        command = MenuEnter;
+                } else if (Event.key.keysym.sym == SDLK_ESCAPE)
                     command = MenuESC;
                 if (command >= 0) {
 #if HAVE_LIBSDL_MIXER
@@ -402,6 +411,8 @@ char *hotseat_label_function (int mid, MenuItem * item)
             return "Start outside ships-1";
         case RndCritical:
             return "Random criticals";
+        case RndWeapon:
+            return "Random weapons";
         }
     }
     return "Foo";
@@ -411,8 +422,9 @@ char *hotseat_label_function (int mid, MenuItem * item)
 static Uint8 hotseat_weaponsel (void)
 {
     SDL_Surface *tmpsurface;
-    struct LevelFile *lev;
     struct LCache *lc, *prev = NULL;
+    struct LevelFile *level;
+    struct dllist *lev;
     int r, rval;
     /* Do some preparations */
     hotseat_weaponsel_mode = 0;
@@ -430,11 +442,13 @@ static Uint8 hotseat_weaponsel (void)
             lev = game_settings.last_level;
     }
     for (r = 0; r < 5; r++) {
+        level = lev->data;
         lc = malloc (sizeof (struct LCache));
         if (weaponsel_levelcache == NULL)
             weaponsel_levelcache = lc;
-        lc->icon = lev->icon;
-        lc->name = renderstring (Bigfont, lev->name, font_color_white);
+        lc->icon = level->settings->icon;
+        lc->name = renderstring (Bigfont, level->settings->mainblock->name,
+                font_color_white);
         lc->next = NULL;
         if (prev)
             prev->next = lc;
@@ -564,7 +578,6 @@ static void draw_hotseat_weaponsel (SDL_Surface * surface)
                 }
                 iconrect.y += rect.h / 2 - lnames->icon->h / 2;
                 SDL_BlitSurface (lnames->icon, NULL, surface, &iconrect);
-                //namerect.x+=lnames->icon->w+5;
             }
             SDL_BlitSurface (lnames->name, NULL, surface, &namerect);
             lnames = lnames->next;
@@ -573,9 +586,10 @@ static void draw_hotseat_weaponsel (SDL_Surface * surface)
         }
     } else {                    /* Draw weapon selection */
         if (!weaponsel_title) {
+            struct LevelFile *level = game_settings.levels->data;
             weaponsel_title =
-                renderstring (Bigfont, game_settings.levels->name,
-                              font_color_blue);
+                renderstring (Bigfont,
+                        level->settings->mainblock->name, font_color_blue);
             title_rect.y = 64 - font_height (Bigfont) / 2;
         }
         if (!weaponsel_prompt) {
@@ -655,17 +669,23 @@ static Uint8 hotseat_weaponsel_eventloop ()
         case SDL_KEYDOWN:
             if (Event.key.keysym.sym == SDLK_F11)
                 screenshot ();
-            else if (Event.key.keysym.sym == SDLK_F12)
-                SDL_WM_ToggleFullScreen (screen);
             else if (hotseat_weaponsel_mode == 0) {     /* Level selection mode */
                 if (Event.key.keysym.sym == SDLK_ESCAPE)
                     return 1;
                 else if (Event.key.keysym.sym == SDLK_RETURN
-                         || Event.key.keysym.sym == SDLK_KP_ENTER)
-                    hotseat_weaponsel_mode++;
+                         || Event.key.keysym.sym == SDLK_KP_ENTER) {
+                    if((Event.key.keysym.mod & (KMOD_LALT|KMOD_RALT))) {
+                        SDL_WM_ToggleFullScreen (screen);
+                    } else {
+                        if(game_settings.playmode==RndWeapon)
+                            return 0;
+                        else
+                            hotseat_weaponsel_mode++;
+                    }
+                }
                 else if (Event.key.keysym.sym == SDLK_LEFT || Event.key.keysym.sym == SDLK_UP) {        /* Level-- */
                     struct LCache *lcache = weaponsel_levelcache;
-                    struct LevelFile *lev;
+                    struct dllist *lev;
                     if (game_settings.levels->prev == NULL)
                         game_settings.levels = game_settings.last_level;
                     else
@@ -684,14 +704,17 @@ static Uint8 hotseat_weaponsel_eventloop ()
                     lcache = weaponsel_levelcache;
                     weaponsel_levelcache = malloc (sizeof (struct LCache));
                     weaponsel_levelcache->next = lcache;
-                    weaponsel_levelcache->icon = lev->icon;
+                    weaponsel_levelcache->icon =
+                        ((struct LevelFile*)lev->data)->settings->icon;
                     weaponsel_levelcache->name =
-                        renderstring (Bigfont, lev->name, font_color_white);
+                        renderstring (Bigfont,
+                            ((struct LevelFile*)lev->data)->settings->mainblock->name,
+                            font_color_white);
                     needupdate = 1;
 
                 } else if (Event.key.keysym.sym == SDLK_RIGHT || Event.key.keysym.sym == SDLK_DOWN) {   /* Level++ */
                     struct LCache *lcache = weaponsel_levelcache->next;
-                    struct LevelFile *lev;
+                    struct dllist *lev;
                     if (game_settings.levels->next == NULL)
                         game_settings.levels = game_settings.first_level;
                     else
@@ -710,9 +733,11 @@ static Uint8 hotseat_weaponsel_eventloop ()
                     lcache->next = malloc (sizeof (struct LCache));
                     lcache = lcache->next;
                     lcache->next = NULL;
-                    lcache->icon = lev->icon;
+                    lcache->icon = ((struct LevelFile*)lev->data)->settings->icon;
                     lcache->name =
-                        renderstring (Bigfont, lev->name, font_color_white);
+                        renderstring (Bigfont,
+                                ((struct LevelFile*)lev->data)->settings->mainblock->name,
+                                font_color_white);
                     needupdate = 1;
                 }
             } else {            /* Weapon selection mode */
