@@ -1,6 +1,6 @@
 /*
  * Luola - 2D multiplayer cavern-flying game
- * Copyright (C) 2003 Calle Laakkonen
+ * Copyright (C) 2003-2004 Calle Laakkonen
  *
  * File        : hotseat.h
  * Description : Hotseat game support code
@@ -24,11 +24,10 @@
 #ifndef HOTSEAT_H
 #define HOTSEAT_H
 
-/* Initialization and deinitialization */
-extern void init_hotseat(void);
-extern void deinit_hotseat(void);
+/* Initialization */
+extern int init_hotseat (void);
 
 /* Start a normal hotseat game */
-extern void hotseat_game(void);
+extern void hotseat_game (void);
 
 #endif
