@@ -281,33 +281,50 @@ int init_intro (void) {
                                font_color_green, 0, 0);
     /* Build level settings menu */
     menulist[5] = create_menu (MENU_ID_LEVEL,
-                               MNU_ITEM_SEP, 0, MNU_OPT_LABEL,
-                               "Level settings", MNU_OPT_ALIGN,
-                               MNU_ALIGN_CENTER, MNU_OPT_COLOR,
-                               font_color_gray, 0, MNU_ITEM_SEP, 0, 0,
+                               /* --- */
+                               MNU_ITEM_SEP, 0,
+                               /* Level settings */
+                               MNU_OPT_LABEL, "Level settings",
+                               MNU_OPT_ALIGN, MNU_ALIGN_CENTER,
+                               MNU_OPT_COLOR, font_color_gray, 0,
+                               /* --- */
+                               MNU_ITEM_SEP, 0, 0,
+                               /* Critters */
                                MNU_ITEM_SUBMENU, MENU_ID_CRITTER,
                                MNU_OPT_LABEL, "Critter settings",
                                MNU_OPT_VALUE, MENU_ID_CRITTER, 0,
                                MNU_ITEM_SEP, 0, MNU_OPT_LABEL, "- - -", 0,
+                               /* Base indestruct */
                                MNU_ITEM_TOGGLE, 1, MNU_OPT_LABEL,
                                "Bases are %s", MNU_OPT_VALUE_TYPE,
                                MNU_TYP_INT, MNU_OPT_VALUE,
                                &game_settings.ls.indstr_base,
                                MNU_OPT_TOGGLE_TEXTS, "indestructable",
-                               "destructable", 0, MNU_ITEM_VALUE, 2,
+                               "destructable", 0,
+                               /* Base regen */
+                               MNU_ITEM_TOGGLE,2,
+                               MNU_OPT_LABEL, "Base regeneration is %s",
+                               MNU_OPT_VALUE_TYPE, MNU_TYP_INT,
+                               MNU_OPT_VALUE, &game_settings.base_regen,0,
+                               /* Jumpgates */
+                               MNU_ITEM_VALUE, 3,
                                MNU_OPT_LABEL, "Jump gates: %d pairs",
                                MNU_OPT_VALUE_TYPE, MNU_TYP_INT,
                                MNU_OPT_VALUE, &game_settings.ls.jumpgates,
                                MNU_OPT_MINVALUE, 0, MNU_OPT_MAXVALUE, 5, 0,
-                               MNU_ITEM_VALUE, 3, MNU_OPT_LABEL,
+                               /* Turrets */
+                               MNU_ITEM_VALUE, 4, MNU_OPT_LABEL,
                                "Turrets: %d", MNU_OPT_VALUE_TYPE,
                                MNU_TYP_INT, MNU_OPT_VALUE,
                                &game_settings.ls.turrets, MNU_OPT_MINVALUE, 0,
-                               MNU_OPT_MAXVALUE, 15, 0, MNU_ITEM_TOGGLE, 4,
+                               MNU_OPT_MAXVALUE, 15, 0,
+                               /* Snowfall */
+                               MNU_ITEM_TOGGLE, 5,
                                MNU_OPT_LABEL, "Snowfall is %s",
                                MNU_OPT_VALUE_TYPE, MNU_TYP_INT,
                                MNU_OPT_VALUE, &game_settings.ls.snowfall, 0,
-                               MNU_ITEM_TOGGLE, 5, MNU_OPT_LABEL,
+                               /* Stars */
+                               MNU_ITEM_TOGGLE, 6, MNU_OPT_LABEL,
                                "Stars are %s", MNU_OPT_VALUE_TYPE,
                                MNU_TYP_INT, MNU_OPT_VALUE,
                                &game_settings.ls.stars, 0, MNU_ITEM_RETURN,
@@ -519,8 +536,6 @@ static Uint8 intro_event_loop (void) {
                 } else {
                     if (Event.key.keysym.sym == SDLK_F11)
                         screenshot ();
-                    else if (Event.key.keysym.sym == SDLK_F12)
-                        SDL_WM_ToggleFullScreen (screen);
                     else if (Event.key.keysym.sym == SDLK_UP)
                         command = MenuUp;
                     else if (Event.key.keysym.sym == SDLK_DOWN)
@@ -529,8 +544,12 @@ static Uint8 intro_event_loop (void) {
                         command = MenuLeft;
                     else if (Event.key.keysym.sym == SDLK_RIGHT)
                         command = MenuRight;
-                    else if (Event.key.keysym.sym == SDLK_RETURN)
-                        command = MenuEnter;
+                    else if (Event.key.keysym.sym == SDLK_RETURN) {
+                        if((Event.key.keysym.mod & (KMOD_LALT|KMOD_RALT)))
+                            SDL_WM_ToggleFullScreen(screen);
+                        else
+                            command = MenuEnter;
+                    }
                     else if (Event.key.keysym.sym == SDLK_ESCAPE)
                         command = MenuESC;
                 }
