@@ -45,18 +45,18 @@ typedef struct {
 
 /* Override block */
 typedef struct {
-    Uint8 indstr_base;
-    Uint8 critters_enabled;
-    Uint8 stars;
-    Uint8 snowfall;
-    Uint8 turrets;
-    Uint8 jumpgates;
-    Uint8 cows;
-    Uint8 fish;
-    Uint8 birds;
-    Uint8 bats;
-    Uint8 soldiers;
-    Uint8 helicopters;
+    int indstr_base;
+    int critters;
+    int stars;
+    int snowfall;
+    int turrets;
+    int jumpgates;
+    int cows;
+    int fish;
+    int birds;
+    int bats;
+    int soldiers;
+    int helicopters;
 } LSB_Override;
 
 /* Objects block */
@@ -83,22 +83,10 @@ typedef struct {
     SDL_Surface *icon;
 } LevelSettings;
 
-/* Just the settings needed to display a level */
-typedef struct {
-    LSB_Main *mainblock;
-    SDL_Surface *icon;
-} LevelInfo;
-
 /* Load a text mode configuration file */
-LevelSettings *load_level_config (const char *filename, int loadextra);
+LevelSettings *load_level_config (const char *filename);
 
 /* Load a binary configuration file */
 LevelSettings *load_level_config_rw (SDL_RWops * rw, int len);
 
-/* Get the important parts of a text mode configuration file */
-LevelInfo *quickload_levelsettings (const char *filename);
-
-/* Load just the main block from a binary configuration file */
-LevelInfo *quickload_levelsettings_rw (SDL_RWops * rw, int len);
-
 #endif
