@@ -65,6 +65,7 @@ static Star lev_stars[STARCOUNT];
 Uint32 burncolor[FIRE_FRAMES];
 Uint32 lev_watercolrgb[3];
 Uint32 lev_watercol;
+Uint32 lev_basecol;
 SDL_Rect cam_rects[4];
 SDL_Rect lev_rects[4];
 Level lev_level;
@@ -76,7 +77,7 @@ static int default_palette (int col) {
     return TER_FREE;
 }
 
-static char touch_wall (int x, int y)
+static int touch_wall (int x, int y)
 {
     int x1, y1;
     unsigned char solid;
@@ -115,6 +116,7 @@ static void draw_stars (SDL_Rect * cam, SDL_Rect * targ)
     }
 }
 
+/* Draw the level for all players */
 static inline void draw_level (void)
 {
     int p;
@@ -128,7 +130,7 @@ static inline void draw_level (void)
     }
 }
 
-
+/* Initialize level subsystem */
 void init_level (void)
 {
     int r, red, green, blue;
@@ -177,9 +179,10 @@ void init_level (void)
     }
 }
 
-static void find_color(Uint8 color,Uint8 *palette,int palettelen,SDL_Palette *source,SDL_Color **target) {
+/* Find the first occurance of a color in the level palette */
+static void find_color(Uint8 color,Uint8 *palette,SDL_Palette *source,SDL_Color **target) {
     int c=0;
-    while (c < palettelen) {
+    while (c < source->ncolors) {
         if (palette[c]==color) {
             *target=source->colors+c;
             break;
@@ -188,45 +191,28 @@ static void find_color(Uint8 color,Uint8 *palette,int palettelen,SDL_Palette *so
     }
 }
 
+/* Sort base regeneration array */
+static int sort_regen(const void *ptr1,const void *ptr2) {
+    const RegenCoord *c1=ptr1,*c2=ptr2;
+    if(c1->y<c2->y) return 1;
+    else if(c1->y==c2->y) return 0;
+    else return -1;
+}
+
+/* Load level and prepare for new game */
 void load_level (struct LevelFile *lev) {
     SDL_Surface *collmap;
     int x, y, p, r;
     int freepix, otherpix;
     SDL_Color *tmpcol, defaultwater;
-    Uint8 pixelval, *bits, palette[256];
+    Uint8 *bits, palette[256];
+    int basebufsize;
 
     defaultwater.r = 0;
     defaultwater.g = 0;
     defaultwater.b = 255;
-    /* First of all, load level settings */
-    if (lev->compact == 0 && lev->config) {
-        lev->settings =
-            load_level_config (getfullpath
-                               (lev->
-                                user ? USERLEVEL_DIRECTORY : LEVEL_DIRECTORY,
-                                lev->config), 0);
-    } else if (lev->compact) {
-        LDAT *lf;
-        SDL_RWops *rw;
-        lf = ldat_open_file (getfullpath
-                             (lev->
-                              user ? USERLEVEL_DIRECTORY : LEVEL_DIRECTORY,
-                              lev->filename));
-        if (!lf) {
-            printf ("Error occured while opening \"%s\"\n",
-                    getfullpath (lev->
-                                 user ? USERLEVEL_DIRECTORY : LEVEL_DIRECTORY,
-                                 lev->filename));
-            exit (1);
-        }
-        rw = ldat_get_item (lf, "SETTINGS", 0);
-        lev->settings =
-            load_level_config_rw (rw,
-                                  ldat_get_item_length (lf, "SETTINGS", 0));
-        ldat_free (lf);
-    }
     /* Get level palette */
-    if (lev->settings && lev->settings->palette) {
+    if (lev->settings->palette) {
         for (r = 0; r < 256; r++)
             palette[r] = lev->settings->palette->entries[r];
     } else {
@@ -246,14 +232,14 @@ void load_level (struct LevelFile *lev) {
     if (collmap->w != lev_level.width || collmap->h != lev_level.height) {
         printf
             ("Error Collision map image \"%s\" has incorrect size (%dx%d), should be %dx%d !\n",
-             lev->collmap, collmap->w, collmap->h, lev_level.width,
-             lev_level.height);
+             lev->settings->mainblock->collmap, collmap->w, collmap->h,
+             lev_level.width, lev_level.height);
         exit (1);
     }
     /* Get palette entries */
     /* Get water colour */
     tmpcol = &defaultwater;
-    find_color(TER_WATER,palette,256,collmap->format->palette,&tmpcol);
+    find_color(TER_WATER,palette,collmap->format->palette,&tmpcol);
 #if HAVE_LIBSDL_GFX
     lev_watercol =
         (tmpcol->r << 24) + (tmpcol->g << 16) + (tmpcol->b << 8) + 0xFF;
@@ -276,7 +262,7 @@ void load_level (struct LevelFile *lev) {
 #endif
     /* Get snow colour */
     tmpcol = NULL;
-    find_color(TER_SNOW,palette,256,collmap->format->palette,&tmpcol);
+    find_color(TER_SNOW,palette,collmap->format->palette,&tmpcol);
     if (tmpcol) {
 #if HAVE_LIBSDL_GFX
         col_snow =
@@ -286,28 +272,70 @@ void load_level (struct LevelFile *lev) {
             SDL_MapRGB (screen->format, tmpcol->r, tmpcol->g, tmpcol->b);
 #endif
     }
+    /* Get base colour */
+    tmpcol = NULL;
+    find_color(TER_BASE,palette,collmap->format->palette,&tmpcol);
+    if(tmpcol) {
+#if HAVE_LIBSDL_GFX
+        lev_basecol =
+            (tmpcol->r << 24) + (tmpcol->g << 16) + (tmpcol->b << 8) + 0xFF;
+#else
+        lev_basecol =
+            SDL_MapRGB(screen->format, tmpcol->r, tmpcol->g, tmpcol->b);
+#endif
+    }
+    /* Prepare base regeneration array */
+    if(game_settings.base_regen) {
+        basebufsize=512;   /* Some arbitary size */
+        lev_level.base = malloc(sizeof(RegenCoord)*basebufsize);
+    } else {
+        basebufsize=0;
+        lev_level.base = NULL;
+    }
     /* Load data map */
     lev_level.base_area = 0;
+    lev_level.regen_area = 0;
     lev_level.solid = malloc (sizeof (unsigned char *) * lev_level.width);
     freepix = 0;
     otherpix = 0;
     for (x = 0; x < lev_level.width; x++) {
+        bits = ((Uint8 *) collmap->pixels)+x;
         lev_level.solid[x] =
             malloc (sizeof (unsigned char) * lev_level.height);
-        for (y = 0; y < lev_level.height; y++) {
-            bits = ((Uint8 *) collmap->pixels) + y * collmap->pitch + x;
-            pixelval = *((Uint8 *) (bits));
-            lev_level.solid[x][y] = palette[pixelval];
+        for (y = 0; y < lev_level.height; y++,bits+=collmap->pitch) {
+            lev_level.solid[x][y] = palette[*bits];
             if (lev_level.solid[x][y] == TER_FREE
                 || lev_level.solid[x][y] == TER_WATER)
                 freepix++;
             else {
                 otherpix++;
-                if (lev_level.solid[x][y] == TER_BASE)
+                if (lev_level.solid[x][y] == TER_BASE) {
+                    if(lev_level.base) {
+                        lev_level.base[lev_level.base_area].x=x;
+                        lev_level.base[lev_level.base_area].y=y;
+                        if(lev_level.base_area==basebufsize-1) {
+                            basebufsize+=512;
+                            lev_level.base=realloc(lev_level.base,
+                                    sizeof(RegenCoord)*basebufsize);
+                        }
+                    }
                     lev_level.base_area++;
+                }
             }
         }
     }
+    SDL_FreeSurface (collmap);
+    /* Finalize the base regeneration buffer */
+    if(lev_level.base) {
+        lev_level.regen_timer = 0;
+        lev_level.regen_area = lev_level.base_area;
+        if(lev_level.base_area<basebufsize) {
+            basebufsize=lev_level.base_area;
+            lev_level.base=realloc(lev_level.base,
+                    sizeof(RegenCoord)*basebufsize);
+        }
+        qsort(lev_level.base,lev_level.base_area,sizeof(RegenCoord),sort_regen);
+    }
     /* Position players */
     if (game_settings.playmode == OutsideShip
         || game_settings.playmode == OutsideShip1)
@@ -340,7 +368,6 @@ void load_level (struct LevelFile *lev) {
                          TER_FREE);
             }
         }
-    SDL_FreeSurface (collmap);
 }
 
 void unload_level (void)
@@ -351,6 +378,8 @@ void unload_level (void)
     for (x = 0; x < lev_level.width; x++)
         free (lev_level.solid[x]);
     free (lev_level.solid);
+    if(lev_level.base)
+        free(lev_level.base);
     while (level_effects) {
         next = level_effects->next;
         free (level_effects->fx);
@@ -360,7 +389,7 @@ void unload_level (void)
     lev_lastfx = NULL;
 }
 
-char is_walkable (int x, int y)
+int is_walkable (int x, int y)
 {
     int s;
     if (y >= lev_level.height - 1)
@@ -375,7 +404,7 @@ char is_walkable (int x, int y)
     return 1;
 }
 
-char is_water (int x, int y)
+int is_water (int x, int y)
 {
     if (lev_level.solid[x][y] == TER_WATER
         || (lev_level.solid[x][y] >= TER_WATERFU
@@ -385,7 +414,7 @@ char is_water (int x, int y)
 }
 
 /* Pixel perfect collision detection. */
-char hit_solid_line (int startx, int starty, int endx, int endy, int *newx,
+int hit_solid_line (int startx, int starty, int endx, int endy, int *newx,
                      int *newy)
 {
     int dx, dy, ax, ay, sx, sy, x, y, d;
@@ -575,6 +604,26 @@ void animate_level (void)
     int v, tx, ty, nx, ny;
     char solid;
     Particle *part;
+    /* Base regeneration */
+    if(lev_level.base && lev_level.base_area<lev_level.regen_area) {
+        if(lev_level.regen_timer>BASE_REGEN_SPEED) {
+            int r,x,y;
+            lev_level.regen_timer=0;
+            for(r=0;r<lev_level.regen_area;r++) {
+                x=lev_level.base[r].x;
+                y=lev_level.base[r].y;
+                if(lev_level.solid[x][y]==TER_FREE) {
+                    lev_level.solid[x][y]=TER_BASE;
+                    putpixel (lev_level.terrain, x, y, lev_basecol);
+                    lev_level.base_area++;
+                    break;
+                }
+            }
+        } else {
+            lev_level.regen_timer++;
+        }
+    }
+    /* Level effects */
     while (list) {
         next = list->next;
         if (list->fx->type == Fire) {   /* Fire */
@@ -619,8 +668,8 @@ void animate_level (void)
                 }
                 if (list->fx->value == FIRE_SPREAD) {
                     for (f = -M_PI; f < M_PI; f += M_PI / 4.0) {
-                        nx = list->fx->x + round(sin (f) * 4.0);
-                        ny = list->fx->y + round(cos (f) * 4.0);
+                        nx = list->fx->x + round(sin (f) * 3.0);
+                        ny = list->fx->y + round(cos (f) * 3.0);
                         if (nx >= lev_level.width || ny >= lev_level.height
                             || nx <= 0 || ny <= 0)
                             continue;
