@@ -31,6 +31,12 @@
 
 typedef enum { Fire, Ice, Earth, Explosive, Melt } LevelFXType;
 
+struct LevelFile;
+
+typedef struct {
+    int x,y;
+} RegenCoord;
+
 typedef struct {
     int width;                  /* Width of the level in pixels */
     int height;                 /* Height of the level in pixels */
@@ -39,6 +45,9 @@ typedef struct {
     int player_def_x[2][4];     /* Beginning x coordinate for players */
     int player_def_y[2][4];     /* Beginning y coordinate for players */
     int base_area;              /* How many pixels of base terrain we have */
+    RegenCoord *base;           /* Coordinates for bases */
+    int regen_area;             /* How much there is to regenerate */
+    int regen_timer;            /* Base regeneration timer */
 } Level;
 
 /* Globals */
@@ -47,6 +56,8 @@ extern SDL_Rect lev_rects[4];   /* Player screen positions */
 extern Uint32 burncolor[FIRE_FRAMES];
 extern Uint32 lev_watercolrgb[3];
 extern Uint32 lev_watercol;
+extern Uint32 lev_basecol;
+
 extern Level lev_level;
 extern Vector gravity;
 
@@ -55,12 +66,12 @@ extern void init_level (void);
 extern void load_level (struct LevelFile *lev);
 extern void unload_level (void);
 
-extern char is_walkable (int x, int y);
-extern char is_water (int x, int y);
-int find_rainy (int x);
+extern int is_walkable (int x, int y);
+extern int is_water (int x, int y);
+extern int find_rainy (int x);
 
 /* A pixel perfect collision detection */
-extern char hit_solid_line (int startx, int starty, int endx, int endy,
+extern int hit_solid_line (int startx, int starty, int endx, int endy,
                             int *newx, int *newy);
 
 /* Inlines */
@@ -94,9 +105,9 @@ static inline void level_bounds(double *x,double *y) {
 }
 
 /* Level effects */
-void start_burning (int x, int y);
-void start_melting (int x, int y, unsigned int recurse);
-void alter_level (int x, int y, int recurse, LevelFXType type);
-void animate_level (void);
+extern void start_burning (int x, int y);
+extern void start_melting (int x, int y, unsigned int recurse);
+extern void alter_level (int x, int y, int recurse, LevelFXType type);
+extern void animate_level (void);
 
 #endif
