@@ -26,21 +26,15 @@
 
 #include "lconf.h"
 
+typedef enum { LEV_UNKNOWN, LEV_NORMAL, LEV_COMPACT} LevelFormat;
+
 struct LevelFile {
-    char *name;
-    char *filename;
-    char *collmap;
-    char *config;
-    SDL_Surface *icon;
+    char *filename;             /* Level filename */
 
-    Uint8 scalex, scaley;
-    int compact;
-    int user;
+    LevelFormat type;           /* Level type (normal or compact) */
+    int user;                   /* Is the level in user directory */
 
-    LevelSettings *settings;
-
-    struct LevelFile *next;
-    struct LevelFile *prev;
+    LevelSettings *settings;    /* Level settings */
 };
 
 /* Scan the directory pointed by 'dirname' for levels */
@@ -63,3 +57,4 @@ extern SDL_Surface *load_level_art (struct LevelFile *level);
 extern SDL_Surface *load_level_coll (struct LevelFile *level);
 
 #endif
+
