@@ -1,6 +1,6 @@
 /*
  * Luola - 2D multiplayer cavern-flying game
- * Copyright (C) 2003 Calle Laakkonen
+ * Copyright (C) 2001-2005 Calle Laakkonen
  *
  * File        : particle.h
  * Description : Particle engine
@@ -27,25 +27,24 @@
 #include "vector.h"
 
 typedef struct {
-  int x,y;
-  Vector vector;
-  int age;
-  int rd,gd,bd,ad;
-  unsigned char color[4];
-  unsigned char targ_color[4];
+    int x, y;
+    Vector vector;
+    int age;
+    int rd, gd, bd, ad;
+    unsigned char color[4];
+    unsigned char targ_color[4];
 } Particle;
 
 /* Initialization */
-extern void init_particles(void);
-extern void deinit_particles(void);
+extern void init_particles (void);
+extern void clear_particles (void);
 
 /* Handling */
-extern Particle *make_particle(int x,int y,int age);
-extern void addParticle(Particle *newpart);
+extern Particle *make_particle (int x, int y, int age);
 
 /* Animation */
-extern void animate_particles(void);
+extern void animate_particles (void);
 
-extern void calc_color_deltas(Particle *part);
+extern void calc_color_deltas (Particle * part);
 
 #endif
