@@ -197,7 +197,7 @@ void animate_pilots (void) {
         solid = is_walkable (round(newx) + pilot->hx, round(newy) + pilot->hy);
         pilot->onbase = 0;
         if (solid) {
-            if (pilot->toofast>PILOT_TOOFAST) { /* Player hit the ground too fast */
+            if (pilot->toofast>PILOT_TOOFAST && pilot->rope!=USEROPE) { /* Player hit the ground too fast */
                 splatter (round(pilot->x), round(pilot->y), Blood);
                 buryplayer (p);
             }
