@@ -84,12 +84,7 @@ int init_players (void) {
         players[p].specialWeapon = WGrenade;
         players[p].standardWeapon = SShot;
         /* Initialize message surface */
-#if 0
-        plr_messages[p]=SDL_CreateRGBSurface(screen->flags,320,PLR_MESSAGE_H,32,screen->format->Rmask,screen->format->Gmask,screen->format->Bmask,screen->format->Amask);
-        SDL_SetColorKey(plr_messages[p],SDL_SRCCOLORKEY,0);
-#else
         plr_messages[p] = NULL;
-#endif
         plr_weapons[p] = NULL;
     }
     radars_visible = 0;
@@ -103,6 +98,7 @@ int init_players (void) {
     return 0;
 }
 
+/* Prepare players for a new round */
 void reinit_players (void) {
     int p, unlucky = -1;
     endgame = -1;
@@ -130,6 +126,10 @@ void reinit_players (void) {
             SDL_FreeSurface (plr_weapons[p]);
             plr_weapons[p] = NULL;
         }
+        if(game_settings.playmode == RndWeapon) {
+            players[p].standardWeapon = rand()%SWeaponCount;
+            players[p].specialWeapon = rand()%(WeaponCount-1)+1;
+        }
         players[p].weapon_select = 0;
         if (game_settings.playmode == OutsideShip1) {
             if (p != unlucky)
@@ -144,6 +144,7 @@ void reinit_players (void) {
                              players[p].specialWeapon);
         }
         if (game_settings.playmode == RndCritical) {
+            /* Randomize criticals */
             int c, cc;
             cc = rand () % CRITICAL_COUNT * 2;
             for (c = 0; c < cc; c++)
@@ -176,7 +177,6 @@ void reinit_players (void) {
             plr_teams_left++;
     if (plr_teams_left == 1) {
         plr_teams_left++;
-        lev_level.base_area = 0;
     }
     reinit_animation ();
 }
@@ -606,7 +606,7 @@ int hearme (int x, int y) {
 
 
 void set_player_message (unsigned char plr, FontSize size, SDL_Color color,
-                         int dur, char *msg, ...)
+                         int dur, const char *msg, ...)
 {
     char buf[256];
     va_list ap;
@@ -708,8 +708,8 @@ void recall_ship (int plr) {
     }
     /* Recall the ship */
     if (ship) {     /* Teleport the existing ship */
-        drop_jumppoint (tx, ty, plr + 20);
         drop_jumppoint (ship->x, ship->y, plr + 20);
+        drop_jumppoint (tx, ty, plr + 20);
         ship->vector.x = 0;
         ship->vector.y = 0;
     } else {        /* Ship probably destroyed, create a new one */
