@@ -63,7 +63,7 @@ extern int find_player (struct Ship * ship);
 extern void buryplayer (int plr);
 extern void eject_pilot (int plr);
 extern void set_player_message (unsigned char plr, FontSize size,
-                                SDL_Color color, int dur, char *msg, ...);
+                                SDL_Color color, int dur, const char *msg, ...);
 extern void player_cleanup (void);
 extern void recall_ship (int plr);
 
