@@ -638,13 +638,16 @@ void animate_ships (void) {
                 ship->vector.y = 0;
             } else {
                 if (ship->vector.y > 0) {       /* Burrow in snow */
+                    int snowx,snowy;
+                    snowx = round(newx);
+                    snowy = round(newy);
                     if (solid == TER_SNOW) {
-                        putpixel (lev_level.terrain, newx, newy, col_black);
-                        lev_level.solid[round(newx)][round(newy)] = TER_FREE;
+                        putpixel (lev_level.terrain, snowx, snowy, col_black);
+                        lev_level.solid[snowx][snowy] = TER_FREE;
                     } else {
-                        putpixel (lev_level.terrain, newx, newy,
+                        putpixel (lev_level.terrain, snowx, snowy,
                                   lev_watercol);
-                        lev_level.solid[round(newx)][round(newy)] = TER_WATER;
+                        lev_level.solid[snowx][snowy] = TER_WATER;
                     }
                     add_snowflake (round(ship->x), round(ship->y));
                 }
@@ -656,7 +659,7 @@ void animate_ships (void) {
                 ship->onbase = 1;
                 if (ship->health < 1 && !ship->shieldup) {      /* Repair the ship */
                     Particle *spark;
-                    ship->health += 0.002;
+                    ship->health += 0.0012;
                     /* Special effects */
                     spark =
                         make_particle (ship->x + (rand () % 16) - 8,
@@ -670,14 +673,14 @@ void animate_ships (void) {
                     spark->gd = -100;
                     spark->bd = -15;
                 }
-                if (ship->health > 1)
-                    ship->health = 1;
+                if (ship->health > 1.0)
+                    ship->health = 1.0;
                 if (!ship->shieldup && !ship->repairing
                     && !ship->fire_special_weapon && ship->visible) {
-                    if (ship->energy < 1)
-                        ship->energy += 0.002;
-                    if (ship->energy > 1)
-                        ship->energy = 1;
+                    if (ship->energy < 1.0)
+                        ship->energy += 0.0014;
+                    else if (ship->energy > 1.0)
+                        ship->energy = 1.0;
                     if (ship->criticals && rand () % 10 == 0)
                         ship_critical (ship, 1);
                 }
@@ -989,8 +992,10 @@ static void ship_exhaust (struct Ship * ship, Vector vec, signed char solid)
 }
 
 /* Player special features such as cloaking device */
-static void ship_specials (struct Ship * ship)
-{
+static void ship_specials (struct Ship * ship) {
+    if(ship->special == WRepair && ship->criticals && rand () % 32 == 0) {
+            ship_critical (ship, 1);
+    }
     if (ship->tagged) {
         ship_tagged (ship);
     }
@@ -1079,8 +1084,6 @@ static void ship_specials (struct Ship * ship)
 #endif
             ship->energy -= 0.001;
         ship->health += 0.0008;
-        if (ship->criticals && rand () % 6 == 0)
-            ship_critical (ship, 1);
         if (ship->health >= 1) {
             ship->health = 1;
             ship->repairing = 0;
