@@ -24,12 +24,17 @@
 #ifndef STRINGUTIL_H
 #define STRINGUTIL_H
 
+/* Remove whitespace from beginning and end of the string */
 extern char *strip_white_space (const char *str);
+
+/* Split a string in two parts. Whitespace is removed */
 extern int split_string (char *str, char delim, char **left, char **right);
 
-extern char *controller_name (int type);
-extern char *weap2str (int weapon);
-extern char *sweap2str (int weapon);
-extern char *critical2str (int critical);
+extern const char *controller_name (int type);
+extern const char *weap2str (int weapon);
+extern const char *sweap2str (int weapon);
+extern const char *critical2str (int critical);
+extern const char *critter2str (int critter);
+extern int name2terrain(const char *name);
 
 #endif
