@@ -23,16 +23,18 @@
 
 #include "vector.h"
 
-Vector makeVector(double X,double Y) {
-  Vector newVec;
-  newVec.x = X;
-  newVec.y = Y;
-  return newVec;
+Vector makeVector (double X, double Y)
+{
+    Vector newVec;
+    newVec.x = X;
+    newVec.y = Y;
+    return newVec;
 }
 
-Vector oppositeVector(Vector *vec) {
-  Vector opp;
-  opp.x=-vec->x;
-  opp.y=-vec->y;
-  return opp;
+Vector oppositeVector (Vector * vec)
+{
+    Vector opp;
+    opp.x = -vec->x;
+    opp.y = -vec->y;
+    return opp;
 }
