@@ -29,18 +29,19 @@
 #endif
 
 typedef struct {
-  double x;
-  double y;
+    double x;
+    double y;
 } Vector;
 
-extern Vector makeVector(double X,double Y);
-extern Vector oppositeVector(Vector *vec);
+extern Vector makeVector (double X, double Y);
+extern Vector oppositeVector (Vector * vec);
 
-static inline Vector addVectors(Vector *v1,Vector *v2) {
-  Vector result;
-  result.x = v1->x + v2->x;
-  result.y = v1->y + v2->y;
-  return result;
+static inline Vector addVectors (Vector * v1, Vector * v2)
+{
+    Vector result;
+    result.x = v1->x + v2->x;
+    result.y = v1->y + v2->y;
+    return result;
 }
 
 #endif
