@@ -128,6 +128,7 @@ static inline void draw_weather_fx (struct WeatherFX *fx)
 void animate_weather (void) {
     struct dllist *list=weather_list;
     signed char solid;
+    int dx;
     if (weather_windy <= 0) {
         int tmpi;
         weather_windy = rand () % MAX_WIND_TIME;
@@ -171,8 +172,9 @@ void animate_weather (void) {
             break;
         case Snowflake:
             fx->y++;
-            fx->x += (rand () % 4) - 2 + round (weather_wind_vector);
-            if (fx->y >= lev_level.height || fx->x <= 0 || fx->x >= lev_level.width) {
+            dx = (rand () % 4) - 2 + round (weather_wind_vector);
+            fx->x += dx;
+            if (fx->y >= lev_level.height || fx->x <= 1 || fx->x >= lev_level.width-1) {
                 free(fx);
                 if(list==weather_list)
                     weather_list=dllist_remove(list);
@@ -182,12 +184,14 @@ void animate_weather (void) {
             }
             solid = hit_solid (fx->x, fx->y);
             if (solid) {
-                alter_level (fx->x, fx->y - 1, 1, Ice);     /* change the recurse value (1) into 2 to get a nice thick coating of snow... ;) */
-                free(fx);
-                if(list==weather_list)
-                    weather_list=dllist_remove(list);
-                else
-                    dllist_remove(list);
+                if( hit_solid(fx->x+(dx<0?1:-1),fx->y) ) {
+                    alter_level (fx->x, fx->y - 1, 1, Ice);     /* change the recurse value (1) into 2 to get a nice thick coating of snow... ;) */
+                    free(fx);
+                    if(list==weather_list)
+                        weather_list=dllist_remove(list);
+                    else
+                        dllist_remove(list);
+                }
             }
             break;
         }
