@@ -1,6 +1,6 @@
 /*
  * Luola - 2D multiplayer cavern-flying game
- * Copyright (C) 2003 Calle Laakkonen
+ * Copyright (C) 2003-2005 Calle Laakkonen
  *
  * File        : lconf.c
  * Description : Level configuration file parsing
@@ -27,7 +27,6 @@
 
 #include "stringutil.h"
 #include "lconf.h"
-#include "game.h"               /* Use game_settings.ls to get default values */
 #include "sbmp.h"
 
 /* Internally used functions */
@@ -45,10 +44,10 @@ static int readObjectsBlockRW (LevelSettings * settings, SDL_RWops * rw,
                                int len);
 static int readPaletteBlockRW (LevelSettings * settings, SDL_RWops * rw,
                                int len);
-static int readIconRW (LevelInfo * info, SDL_RWops * rw, int len);
+static int readIconRW (LevelSettings * info, SDL_RWops * rw, int len);
 
 /* Load the configuration file from file */
-LevelSettings *load_level_config (const char *filename, int loadextra)
+LevelSettings *load_level_config (const char *filename)
 {
     FILE *fp;
     char *line;
@@ -75,7 +74,7 @@ LevelSettings *load_level_config (const char *filename, int loadextra)
             settings->objects = readObjectsBlock (fp);
         else if (strcmp (line, "[palette]") == 0)
             settings->palette = readPaletteBlock (fp);
-        else if (strcmp (line, "[icon]") == 0 && loadextra)
+        else if (strcmp (line, "[icon]") == 0)
             settings->icon = readIconBlock (fp);
         free (line);
     }
@@ -112,9 +111,8 @@ LevelSettings *load_level_config_rw (SDL_RWops * rw, int len)
             read += readPaletteBlockRW (settings, rw, l);
             break;
         case 0x05:
-            read += l;
-            SDL_RWseek (rw, l, SEEK_CUR);
-            break;              /* We (currently) don't need to load the icon here */
+            read += readIconRW(settings,rw,l);
+            break;
         default:
             printf
                 ("Warning: Unrecognized toplevel block 0x%x ! (skipping %d bytes...)\n",
@@ -147,7 +145,7 @@ static SDL_Surface *readIconBlock (FILE * fp)
 }
 
 /* Read the icon from a binary level settings file */
-static int readIconRW (LevelInfo * info, SDL_RWops * rw, int len)
+static int readIconRW (LevelSettings *settings, SDL_RWops * rw, int len)
 {
     Uint32 colorkey;
     Uint8 hascolorkey;
@@ -160,74 +158,13 @@ static int readIconRW (LevelInfo * info, SDL_RWops * rw, int len)
     len -= read;
     if (len)
         SDL_RWseek (rw, len, SEEK_CUR);
-    info->icon = sbmp_to_surface (data);
+    settings->icon = sbmp_to_surface (data);
     if (hascolorkey)
-        SDL_SetColorKey (info->icon, SDL_SRCCOLORKEY, colorkey);
+        SDL_SetColorKey (settings->icon, SDL_SRCCOLORKEY, colorkey);
     free (data);
     return read + len;
 }
 
-
-/* Load just the main block and icon from a text mode configuration file */
-LevelInfo *quickload_levelsettings (const char *filename)
-{
-    LevelInfo *info;
-    FILE *fp;
-    char *line;
-    fp = fopen (filename, "r");
-    if (!fp) {
-        printf ("Error ! Could not open configuration file \"%s\" !\n",
-                filename);
-        exit (1);
-    }
-    info = malloc (sizeof (LevelInfo));
-    memset (info, 0, sizeof (LevelInfo));
-    /* Read */
-    while ((line = read_line (fp))) {
-        if (line[0] == '\0')
-            continue;
-        if (strcmp (line, "[main]") == 0)
-            info->mainblock = readMainBlock (fp);
-        else if (strcmp (line, "[icon]") == 0)
-            info->icon = readIconBlock (fp);
-        free (line);
-    }
-    fclose (fp);
-    return info;
-}
-
-/* Load just the main block and icon from a binary configuration file */
-LevelInfo *quickload_levelsettings_rw (SDL_RWops * rw, int len)
-{
-    LevelSettings settings;
-    LevelInfo *info;
-    Uint16 l;
-    Uint8 type;
-    int read = 0;
-    info = malloc (sizeof (LevelInfo));
-    memset (info, 0, sizeof (LevelInfo));
-    /* Read */
-    while (read < len) {
-        read += SDL_RWread (rw, &l, 2, 1) * 2;
-        read += SDL_RWread (rw, &type, 1, 1);
-        switch (type) {
-        case 0x01:
-            read += readMainBlockRW (&settings, rw, l);
-            info->mainblock = settings.mainblock;
-            break;
-        case 0x05:
-            read += readIconRW (info, rw, l);
-            break;
-        default:
-            SDL_RWseek (rw, l, SEEK_CUR);
-            read += l;
-            break;
-        }
-    }
-    /* Finished */
-    return info;
-}
-
 /* Read the main block */
 static LSB_Main *readMainBlock (FILE * fp)
 {
@@ -353,6 +290,21 @@ static int readMainBlockRW (LevelSettings * settings, SDL_RWops * rw, int len)
     return read;
 }
 
+static void init_override_block(LSB_Override *block) {
+    block->indstr_base = -1;
+    block->critters = -1;
+    block->stars = -1;
+    block->snowfall = -1;
+    block->turrets = -1;
+    block->jumpgates = -1;
+    block->cows = -1;
+    block->fish = -1;
+    block->birds = -1;
+    block->bats = -1;
+    block->soldiers = -1;
+    block->helicopters = -1;
+}
+
 /* Read the override block */
 static LSB_Override *readOverrideBlock (FILE * fp)
 {
@@ -360,18 +312,7 @@ static LSB_Override *readOverrideBlock (FILE * fp)
     char *left, *right;
     char *line;
     override = malloc (sizeof (LSB_Override));
-    override->indstr_base = game_settings.ls.indstr_base;
-    override->critters_enabled = 0;
-    override->stars = game_settings.ls.stars;
-    override->snowfall = game_settings.ls.snowfall;
-    override->turrets = game_settings.ls.turrets;
-    override->jumpgates = game_settings.ls.jumpgates;
-    override->cows = game_settings.ls.cows;
-    override->fish = game_settings.ls.birds;
-    override->birds = game_settings.ls.fish;
-    override->bats = game_settings.ls.bats;
-    override->soldiers = game_settings.ls.soldiers;
-    override->helicopters = game_settings.ls.helicopters;
+    init_override_block(override);
     while ((line = read_line (fp))) {
         if (line[0] == '\0')
             continue;
@@ -384,10 +325,14 @@ static LSB_Override *readOverrideBlock (FILE * fp)
             printf ("Warning: Malformed line:\n \"%s\"\n", line);
             continue;
         }
-        if (strcmp (left, "critters_enabled") == 0)
-            override->critters_enabled = atoi (right);
+        if (strcmp (left, "critters") == 0)
+            override->critters = atoi (right);
         else if (strcmp (left, "bases_indestructable") == 0)
             override->indstr_base = atoi (right);
+        else if(strcmp (left,"snowfall")==0)
+            override->snowfall = atoi(right);
+        else if(strcmp (left,"stars")==0)
+            override->stars = atoi(right);
         else if (strcmp (left, "turrets") == 0)
             override->turrets = atoi (right);
         else if (strcmp (left, "jumpgates") == 0)
@@ -419,60 +364,57 @@ static int readOverrideBlockRW (LevelSettings * settings, SDL_RWops * rw,
                                 int len)
 {
     LSB_Override *override;
+    Uint8 type,byte;
     int read = 0;
-    Uint8 type;
     override = malloc (sizeof (LSB_Override));
-    override->indstr_base = game_settings.ls.indstr_base;
-    override->critters_enabled = 0;
-    override->stars = game_settings.ls.stars;
-    override->snowfall = game_settings.ls.snowfall;
-    override->turrets = game_settings.ls.turrets;
-    override->jumpgates = game_settings.ls.jumpgates;
-    override->cows = game_settings.ls.cows;
-    override->fish = game_settings.ls.birds;
-    override->birds = game_settings.ls.fish;
-    override->bats = game_settings.ls.bats;
-    override->soldiers = game_settings.ls.soldiers;
-    override->helicopters = game_settings.ls.helicopters;
+    init_override_block(override);
     while (read < len) {
         read += SDL_RWread (rw, &type, 1, 1);
         switch (type) {
-        case 0x01:             /* Critters enabled */
-            read += SDL_RWread (rw, &override->critters_enabled, 1, 1);
+        case 0x01:             /* Critters */
+            read += SDL_RWread (rw, &byte, 1, 1);
+            override->critters=byte;
             break;
         case 0x02:             /* Bases indestructable */
-            read += SDL_RWread (rw, &override->indstr_base, 1, 1);
+            read += SDL_RWread (rw, &byte, 1, 1);
+            override->indstr_base=byte;
             break;
         case 0x03:             /* Stars */
-            read += SDL_RWread (rw, &override->stars, 1, 1);
+            read += SDL_RWread (rw, &byte, 1, 1);
+            override->stars=byte;
             break;
         case 0x04:             /* Snowfall */
-            read += SDL_RWread (rw, &override->snowfall, 1, 1);
+            read += SDL_RWread (rw, &byte, 1, 1);
+            override->snowfall=byte;
             break;
         case 0x05:             /* Turrets */
-            read += SDL_RWread (rw, &override->turrets, 1, 1);
+            read += SDL_RWread (rw, &byte, 1, 1);
+            override->turrets=byte;
             break;
         case 0x06:             /* Jumpgates */
-            read += SDL_RWread (rw, &override->jumpgates, 1, 1);
+            read += SDL_RWread (rw, &byte, 1, 1);
+            override->jumpgates=byte;
             break;
         case 0x07:             /* Cows */
-            read += SDL_RWread (rw, &override->cows, 1, 1);
+            read += SDL_RWread (rw, &byte, 1, 1);
+            override->cows=byte;
             break;
         case 0x08:             /* Fish */
-            read += SDL_RWread (rw, &override->fish, 1, 1);
+            read += SDL_RWread (rw, &byte, 1, 1);
+            override->fish=byte;
             break;
         case 0x09:             /* Birds */
-            read += SDL_RWread (rw, &override->birds, 1, 1);
+            read += SDL_RWread (rw, &byte, 1, 1);
+            override->birds=byte;
             break;
         case 0x0a:             /* Bats */
-            read += SDL_RWread (rw, &override->bats, 1, 1);
+            read += SDL_RWread (rw, &byte, 1, 1);
+            override->bats=byte;
             break;
         default:
-            printf
-                ("WARNING !! Unknown override block item 0x%x ! (skipping one byte...)\n",
-                 type);
-            SDL_RWseek (rw, 1, SEEK_CUR);
-            read++;
+            read+=SDL_RWread(rw,&byte,1,1);
+            printf("warning! Unknown override block item 0x%x=0x%x!\n",
+                 type,byte);
             break;
         }
     }
@@ -557,6 +499,7 @@ static LSB_Objects *readObjectsBlock (FILE * fp)
     return first;
 }
 
+#if 0
 static LSB_Palette *readPaletteBlock (FILE * fp)
 {
     LSB_Palette *palette;
@@ -638,6 +581,60 @@ static LSB_Palette *readPaletteBlock (FILE * fp)
     }
     return palette;
 }
+#endif
+
+static LSB_Palette *readPaletteBlock (FILE * fp) {
+    LSB_Palette *palette;
+    char *line;
+    int mapto;
+
+    palette = malloc (sizeof (LSB_Palette));
+    memset (palette->entries, 0, 256);
+    while ((line = read_line (fp))) {
+        char *left=NULL,*right=NULL;
+        if (line[0] == '\0') {
+            free(line);
+            continue;
+        }
+        if (strcmp (line, "[end]") == 0) {
+            free (line);
+            break;
+        }
+        split_string (line, '=', &left, &right);
+        free(line);
+        if (left == NULL || right == NULL) {
+            printf ("Warning: Malformed line:\n \"%s\"\n", line);
+            continue;
+        }
+        mapto = name2terrain(right);
+        if(strchr(left,'-')) { /* Range */
+            int from,to;
+            sscanf(left,"%d - %d",&from,&to);
+            if(from<0||from>255||to<0||to>255) {
+                printf("Error: palette map range %d-%d out of bounds (0-255!",
+                    from,to);
+                free(left);
+                free(right);
+                continue;
+            } else if(to<from) {
+                int tmp;
+                tmp=to; to=from; from=tmp;
+            }
+            for(;from<=to;from++) palette->entries[from]=mapto;
+        } else { /* Single value */
+            int index;
+            index=atoi(left);
+            if(index<0 || index>255) {
+                printf("Palette map index %d out of bounds (0-255)!\n",index);
+            } else {
+                palette->entries[index]=mapto;
+            }
+            free(left);
+            free(right);
+        }
+    }
+    return palette;
+}
 
 /* Read objects block (binary) */
 static int readObjectsBlockRW (LevelSettings * settings, SDL_RWops * rw,
