@@ -106,80 +106,90 @@ static int mainblock2bin(LSB_Main *block,SDL_RWops *rw, int *size) {
 
 /* Convert the override block into binary datastream */
 static int overrideblock2bin(LSB_Override *block,SDL_RWops *rw, int *size) {
-  Uint16 len=0,i16;
-  Uint8 type=0x02,i8;
-  int r;
-  /* Block header */
-  SDL_RWwrite(rw,&len,2,1);	/* We'll fix this later */
-  SDL_RWwrite(rw,&type,1,1);
-  /* Critters enabled */
-  if(block->critters_enabled!=0xff) {
-    type=0x01;
-    SDL_RWwrite(rw,&type,1,1); len++;
-    SDL_RWwrite(rw,&block->critters_enabled,1,1); len++;
-  }
-  /* Indestructable bases */
-  if(block->indstr_base!=0xff) {
-    type=0x02;
-    SDL_RWwrite(rw,&type,1,1); len++;
-    SDL_RWwrite(rw,&block->indstr_base,1,1); len++;
-  }
-  /* Stars */
-  if(block->stars!=0xff) {
-    type=0x03;
-    SDL_RWwrite(rw,&type,1,1); len++;
-    SDL_RWwrite(rw,&block->stars,1,1); len++;
-  }
-  /* Snowfall */
-  if(block->snowfall!=0xff) {
-    type=0x04;
-    SDL_RWwrite(rw,&type,1,1); len++;
-    SDL_RWwrite(rw,&block->snowfall,1,1); len++;
-  }
-  /* Turrets */
-  if(block->turrets!=0xff) {
-    type=0x05;
-    SDL_RWwrite(rw,&type,1,1); len++;
-    SDL_RWwrite(rw,&block->turrets,1,1); len++;
-  }
-  /* Jumpgates */
-  if(block->jumpgates!=0xff) {
-    type=0x06;
-    SDL_RWwrite(rw,&type,1,1); len++;
-    SDL_RWwrite(rw,&block->jumpgates,1,1); len++;
-  }
-  /* Cows */
-  if(block->cows!=0xff) {
-    type=0x07;
-    SDL_RWwrite(rw,&type,1,1); len++;
-    SDL_RWwrite(rw,&block->cows,1,1); len++;
-  }
-  /* Fish */
-  if(block->fish!=0xff) {
-    type=0x08;
-    SDL_RWwrite(rw,&type,1,1); len++;
-    SDL_RWwrite(rw,&block->fish,1,1); len++;
-  }
-  /* Birds */
-  if(block->birds!=0xff) {
-    type=0x09;
-    SDL_RWwrite(rw,&type,1,1); len++;
-    SDL_RWwrite(rw,&block->birds,1,1); len++;
-  }
-  /* Bats */
-  if(block->bats!=0xff) {
-    type=0x0a;
-    SDL_RWwrite(rw,&type,1,1); len++;
-    SDL_RWwrite(rw,&block->bats,1,1); len++;
-  }
-  /* Set proper length */
-  SDL_RWseek(rw,-(len+3),SEEK_CUR);
-  SDL_RWwrite(rw,&len,2,1);
-  SDL_RWseek(rw,len+1,SEEK_CUR);
-  printf("Override block length: %d (+3 bytes)\n",len);
-  len+=3;
-  /* Done */
-  *size+=len;
+    Uint16 len=0,i16;
+    Uint8 type=0x02,i8,byte;
+    int r;
+    /* Block header */
+    SDL_RWwrite(rw,&len,2,1);	/* We'll fix this later */
+    SDL_RWwrite(rw,&type,1,1);
+    /* Critters enabled */
+    if(block->critters>=0) {
+        byte=block->critters;
+        type=0x01;
+        SDL_RWwrite(rw,&type,1,1); len++;
+        SDL_RWwrite(rw,&byte,1,1); len++;
+    }
+    /* Indestructable bases */
+    if(block->indstr_base>=0) {
+        byte=block->indstr_base;
+        type=0x02;
+        SDL_RWwrite(rw,&type,1,1); len++;
+        SDL_RWwrite(rw,&byte,1,1); len++;
+    }
+    /* Stars */
+    if(block->stars>=0) {
+        byte=block->stars;
+        type=0x03;
+        SDL_RWwrite(rw,&type,1,1); len++;
+        SDL_RWwrite(rw,&byte,1,1); len++;
+    }
+    /* Snowfall */
+    if(block->snowfall>=0) {
+        byte=block->snowfall;
+        type=0x04;
+        SDL_RWwrite(rw,&type,1,1); len++;
+        SDL_RWwrite(rw,&byte,1,1); len++;
+    }
+    /* Turrets */
+    if(block->turrets>=0) {
+        byte=block->turrets;
+        type=0x05;
+        SDL_RWwrite(rw,&type,1,1); len++;
+        SDL_RWwrite(rw,&byte,1,1); len++;
+    }
+    /* Jumpgates */
+    if(block->jumpgates>=0) {
+        byte=block->jumpgates;
+        type=0x06;
+        SDL_RWwrite(rw,&type,1,1); len++;
+        SDL_RWwrite(rw,&byte,1,1); len++;
+    }
+    /* Cows */
+    if(block->cows>=0) {
+        byte=block->cows;
+        type=0x07;
+        SDL_RWwrite(rw,&type,1,1); len++;
+        SDL_RWwrite(rw,&byte,1,1); len++;
+    }
+    /* Fish */
+    if(block->fish>=0) {
+        byte=block->fish;
+        type=0x08;
+        SDL_RWwrite(rw,&type,1,1); len++;
+        SDL_RWwrite(rw,&byte,1,1); len++;
+    }
+    /* Birds */
+    if(block->birds>=0) {
+        byte=block->birds;
+        type=0x09;
+        SDL_RWwrite(rw,&type,1,1); len++;
+        SDL_RWwrite(rw,&byte,1,1); len++;
+    }
+    /* Bats */
+    if(block->bats>=0) {
+        byte=block->bats;
+        type=0x0a;
+        SDL_RWwrite(rw,&type,1,1); len++;
+        SDL_RWwrite(rw,&byte,1,1); len++;
+    }
+    /* Set proper length */
+    SDL_RWseek(rw,-(len+3),SEEK_CUR);
+    SDL_RWwrite(rw,&len,2,1);
+    SDL_RWseek(rw,len+1,SEEK_CUR);
+    printf("Override block length: %d (+3 bytes)\n",len);
+    len+=3;
+    /* Done */
+    *size+=len;
 }
 
 /* Convert the objects block into binary datastream */
